<!-- START doctoc generated TOC please keep comment here to allow auto update -->
<!-- DON'T EDIT THIS SECTION, INSTEAD RE-RUN doctoc TO UPDATE -->
**Table of Contents**

- [YDK bundle](#ydk-bundle)
- [Installation](#installation)

<!-- END doctoc generated TOC please keep comment here to allow auto update -->

<a href="https://github.com/CiscoDevNet/ydk-gen"><img src="https://cloud.githubusercontent.com/assets/17089095/14834057/2e1fe270-0bb7-11e6-9e94-73dd7d71e87d.png" height="240" width="240" ></a>

# YDK bundle

YDK bundle is a package of python API's that are modeled in YANG.

# Installation

Create a source distribution for the bundle:
```
    $ python setup.py sdist
```

Install the bundle:
```
    $ pip install dist/ydk-*.tar.gz
```

